---
name: "\U0001F4A1 Feature request"
about: Suggest an idea for this project
title: "[FEATURE]"
labels: ''
type: 'feature'
assignees: ''

---

**What is the use case?**

**Describe the solution you'd like**

**Additional context**


---
❤️ Contributors, please refer to 📙[Contributing Guide](https://cocoindex.io/docs/about/contributing).
Unless the PR can be sent immediately (e.g. just a few lines of code), we recommend you to leave a comment on the issue like **`I'm working on it`**  or **`Can I work on this issue?`** to avoid duplicating work. Our [Discord server](https://discord.com/invite/zpA9S2DR7s) is always open and friendly.
